#!/bin/bash -f
# -*-TCL-*- this sets TCL mode in both emacs andRamDebugger

#    OutputFile: $2/$1.info
#    ErrorFile: $2/$1.err
#    WarningFile: $2/$1.war

# the next line restarts using command, a tcl shell \
exec "$GIDDEFAULT/command" "$0" "$@"

namespace eval myrun {
    variable exe
    variable has_run 0
}

proc myrun::get_sysinfo {} {
    variable exe

    set remotedir [send create_remote_new_dir ramseries]
    copy_file_to_server -binary 1 $exe $remotedir
    set data [send exec_in_dir $remotedir [file tail $exe] -outputinfo]
    send file delete -force $remotedir
    return $data
}


proc myrun::run_model { more_files gid_model password_file } {
    variable exe
    variable has_run

    set has_run 1
    set l_base [file join $gid_model [file tail [file root $gid_model]]]
    foreach i [list .flavia.res .info .war .err] {
	file delete $l_base$i
    }
    set datfile $l_base.dat

    set remotedir [send create_remote_new_dir ramseries]

    foreach "file t" [list $exe binary $password_file ascii $datfile ascii] {
	switch $t binary { set b 1 } ascii { set b 0 }
	copy_file_to_server -binary $b $file $remotedir
    }
    foreach file $more_files {
	copy_file_to_server -binary 1 $file $remotedir
    }

    if { [file tail $password_file] ne "password.txt" } {
	send file rename [file join $remotedir [file tail $password_file]] \
	    [file join $remotedir password.txt]
    }

    set pid [compass_client::exec_in_dir $remotedir [file tail $exe] -a \
	    [file tail $datfile] &]

    set r_base [file join $remotedir [file tail [file root $gid_model]]]

    after 1000
    set mtime ""
    while 1 {
	if { [send file exists $r_base.info] } {
	    set new_mtime [send file mtime $r_base.info]
	    if { $mtime eq "" || $new_mtime > $mtime } {
		copy_file_from_server $r_base.info $gid_model
	    }
	    set mtime $new_mtime
	}
	if { ![send process_exists $pid] } { break }
	after 5000 [list set waiting_var 1]
	vwait ::waiting_var
    }
    unset pid

    copy_file_from_server -nocomplain 1 -binary 1 $r_base.flavia.res $gid_model
    copy_file_from_server -nocomplain 1 $r_base.info $gid_model
    copy_file_from_server -nocomplain 1 $r_base.war $gid_model
    copy_file_from_server -nocomplain 1 $r_base.err $gid_model

    send file delete -force $remotedir
    unset remotedir
}

proc myrun::finish { basename dir } {
    variable has_run

    set flavia [file join $dir $basename.flavia.res]

    if { !$has_run } {
	set fout [open [file join $dir $basename.err] a]
	puts $fout "Program has not been executed"
	close $fout
    } elseif { [file exists $flavia] && [file size $flavia] > 0 } {
	file delete [file join $dir $basename.dat]
    } else {
	set fout [open [file join $dir $basename.err] a]
	puts $fout "Program failed"
	close $fout
    }
}

lassign $argv basename dir problemtypedir - more_files

set dir [file normalize $dir]
set problemtypedir [file normalize $problemtypedir]
set myrun::exe [file join $problemtypedir exec ramseries.exe]

lappend auto_path [file join $problemtypedir exec] \
    [file join $env(GIDDEFAULT) problemtypes common_lib]
package require Tk

set debug 1
if { $debug } {
    lappend auto_path ~/mytcltk
    #/tcltk/activetcl8.4/lib \
    #/tcltk /tcltk/activetcl8.4/lib/tcllib1.9
    bind all <F12> { package require RamDebugger }
}

package require compass_utils

auto_load compass_client::init_gui
namespace import -force compass_client::*

if { $::tcl_platform(platform) == "windows"} {
    # Global variable "RunningProcess" is written when GiD kills the process
    set RunningProcess running
    trace add variable RunningProcess write "compass_client::gui_exit ;#"
} else {
   signal trap TERM compass_client::gui_exit
}

compass_client::init_gui -infofile_ext .info \
    -run_handler [list myrun::run_model $more_files] \
    -sysinfo_handler myrun::get_sysinfo \
    -exit_handler [list myrun::finish $basename $dir] \
    -hide_model_password -exit_after_analysis \
    -gid_model $dir \
    -password_file [file join $problemtypedir password.txt] \
    -full_error_info 1

vwait forever















